canUseParsedResult property

  1. @override
bool get canUseParsedResult

Indicates whether this analysis rule can work with just the parsed information or if it requires a resolved unit.

Implementation

@override
bool get canUseParsedResult => false;