DeviceAuthCallbacks class
Callback set required for device authentication.
Constructors
- DeviceAuthCallbacks({required AsyncStringCallback cpuId, required AsyncStringCallback uuid, required AsyncIntCallback deviceId, required AsyncStringCallback initialDeviceToken, TokenUpdatedCallback? onTokenUpdated})
-
Creates device auth callbacks.
const
Properties
- cpuId → AsyncStringCallback
-
Resolves the device CPU identifier.
final
- deviceId → AsyncIntCallback
-
Resolves the numeric platform device identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialDeviceToken → AsyncStringCallback
-
Resolves the initial device token used by
/loginDevice.final - onTokenUpdated → TokenUpdatedCallback?
-
Called when the active token changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → AsyncStringCallback
-
Resolves the device UUID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited