UserAuth class
User authentication provider for Spoke.Zone.
- Implemented types
Constructors
- UserAuth({required Uri baseUri, required UserAuthCallbacks callbacks, required Client httpClient, BackoffStrategy? backoffStrategy, DelayFn? delay})
- Creates a user auth provider.
Properties
- baseUri → Uri
-
final
- callbacks → UserAuthCallbacks
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpClient → Client
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cacheToken(
String token) → void -
inherited
-
getAccessToken(
) → Future< String> -
Returns a usable access token, performing login/refresh when needed.
inherited
-
login(
) → Future< String> -
Performs
/loginand returns the current access token. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited